@@ -113,7 +113,11 @@ void MemoryCardManager::DeleteSlot()
 
     if (m_Card->get_slot_is_used(m_SelectedSlot)){
         m_Card->delete_slot(m_SelectedSlot);
+
+        int row = ui->listWidget->currentRow();
         UpdateSlotList();
+        ui->listWidget->setCurrentRow(row);
+        SlotChanged(NULL);
 
         m_Modified = true;
         if (!windowTitle().endsWith("*"))
