@@ -20,7 +20,7 @@ options::options(QWidget *parent) :
     connect(ui->pbnMemoryCard1, SIGNAL(clicked()),this,SLOT(memory_card_1()));
     connect(ui->pbnMemoryCard2, SIGNAL(clicked()),this,SLOT(memory_card_2()));
     connect(ui->pbnConfigAccel, SIGNAL(clicked()), this, SLOT(config_accel()));
-
+    connect(ui->radioButton, SIGNAL(toggled(bool)), this, SLOT(coreChanged(bool)));
     load_cfg();
 
     m_Loop = NULL;
@@ -71,7 +71,7 @@ void options::load_cfg()
     configs << "accel" << "cdda" << "xa" << "rcnt" << "sio" << "spuirq" << "vsync" << "fsaa" << "pcsx-fullscreen";
     configs << "pcsx-fps" << "pcsx-cpu" << "pcsx-nofl" << "mcd1" << "mcd2" << "spu_reverb" << "spu_interpolation";
     configs << "region" << "analog" << "accel_sens" << "accel_y_def" << "accel_max" << "displayon" << "keys";
-    configs << "autosave";
+    configs << "autosave" << "vibration";
 
     ui->radioButton_2->setChecked(true);
     ui->comboBox_5->setCurrentIndex(0);
@@ -83,7 +83,10 @@ void options::load_cfg()
     ui->cmbInterpolation->setCurrentIndex(0);
     ui->cmbRegion->setCurrentIndex(0);
 
-    ui->cmbKeysConfig->setCurrentIndex(-1);
+    if (ui->cmbKeysConfig->findText("Default") != -1)
+        ui->cmbKeysConfig->setCurrentIndex(ui->cmbKeysConfig->findText("Default"));
+    else
+        ui->cmbKeysConfig->setCurrentIndex(-1);
     ui->chkDisplayOn->setChecked(false);
     ui->numSens->setValue(150);
     ui->numYDef->setValue(500);
@@ -228,6 +231,9 @@ void options::load_cfg()
                  case 36:
                      if (value=="1")ui->chkAutosave->setChecked(true);else ui->chkAutosave->setChecked(false);
                      break;
+                 case 37:
+                      if (value=="1")ui->chkVibration->setChecked(true);else ui->chkVibration->setChecked(false);
+                      break;
                  default:
                       qDebug(QString("Undefined setting:%1 = %2").arg(line.at(0)).arg(value).toAscii());
                       break;
@@ -260,15 +266,16 @@ void options::createCfg(){
     current_config<<"-mcd1"<<m_MemoryCard1;
     current_config<<"-mcd2"<<m_MemoryCard2;
 
+    if (ui->cmbKeysConfig->currentIndex()>=0){
+        QHash<QString, QString> kList = keys::configList();
+        current_config << "-keys" << kList[ui->cmbKeysConfig->currentText()];
+    }
+
     if (ui->radioButton_2->isChecked())
     {
         current_core="pcsx";
 
-        if (ui->cmbKeysConfig->currentIndex()>=0){
-            QHash<QString, QString> kList = keys::configList();
-            current_config << "-keys" << kList[ui->cmbKeysConfig->currentText()];
-        }
-
+        if (ui->chkVibration->isChecked())current_config<<"-vibration";
         if (ui->chkAutosave->isChecked())current_config<<"-autosave";
         if (ui->chkDisplayOn->isChecked())current_config<<"-displayon";
         if (ui->chkAnalog->isChecked())current_config<<"-analog";
@@ -378,7 +385,8 @@ void options::save_cfg(){
                    "accel_max=%34\n" \
                    "displayon=%35\n" \
                    "keys=%36\n" \
-                   "autosave=%37\n")
+                   "autosave=%37\n" \
+                   "vibration=%38\n")
             .arg(ui->radioButton_2->isChecked()?"1":"0")
             .arg(ui->checkBox->isChecked()?"1":"0")
             .arg(ui->comboBox_4->currentText())
@@ -415,7 +423,8 @@ void options::save_cfg(){
             .arg(ui->numMaxValue->value())
             .arg(ui->chkDisplayOn->isChecked()?"1":"0")
             .arg(ui->cmbKeysConfig->currentText())
-            .arg(ui->chkAutosave->isChecked()?"1":"0");
+            .arg(ui->chkAutosave->isChecked()?"1":"0")
+            .arg(ui->chkVibration->isChecked()?"1":"0");
 
     QFile file(path);
     QFileInfo pathInfo(path);
@@ -548,3 +557,41 @@ void options::init_data()
     foreach (QString name, keys)
         ui->cmbKeysConfig->addItem(name);
 }
+
+void options::coreChanged(bool)
+{
+    //Check image format compatibility with core:
+    QString core;
+    if(ui->radioButton->isChecked()){
+        core = "psx4m";
+        ui->tabWidget->removeTab(2);
+        ui->tabWidget->insertTab(2, ui->tabPsx4m, "PSX4m");
+    }else{
+        core = "pcsx";
+        ui->tabWidget->removeTab(2);
+        ui->tabWidget->insertTab(2, ui->tabPcsx, "PCSX-ReArmed");
+    }
+
+    if (!game.isEmpty()){
+        if (!isSupported(core, game)){
+            QMessageBox msg(this);
+            msg.setWindowTitle(tr("Warning"));
+            msg.setText(tr("Image format not supported by the selected core."));
+            msg.exec();
+        }
+    }
+}
+
+bool options::isSupported(QString core, QString romFileName)
+{
+    if (core == "pcsx")
+        return true;
+    else{
+        QStringList supported = QStringList() << "bin" << "iso" << "img";
+        QFileInfo f(romFileName);
+        QString ext = f.suffix();
+
+        return supported.contains(ext);
+    }
+    return false;
+}
