@@ -16,6 +16,8 @@ public:
     ~options();
     Ui::options *ui;
 
+    static bool isSupported(QString core, QString romFileName);
+
 public slots:
     void load_cfg();
     void save_cfg();
@@ -28,6 +30,7 @@ public slots:
     void show();
     void accel_toggled(bool toggled);
     void config_accel();
+    void coreChanged(bool);
 
 protected:
     void hideEvent(QHideEvent *);
