@@ -2,15 +2,19 @@
 #define ROMINFO_H
 
 #include <QString>
+#include <QStringList>
 
 class RomInfo
 {
 public:
     RomInfo();
 
+    QString DisplayName;
     QString FilePath;
     QString FileName;
-    QString SaveStateName;
+    QStringList SaveStateNames;
+
+    bool IsMultiDisc() { return SaveStateNames.count() > 1; }
 };
 
 #endif // ROMINFO_H
